# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["Credit"]


class Credit(BaseModel):
    credit_line: Optional[str] = FieldInfo(alias="creditLine", default=None)

    used_credit: Optional[str] = FieldInfo(alias="usedCredit", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .order import Order as Order
from .portfolio import Portfolio as Portfolio
from .trading_list_response import TradingListResponse as TradingListResponse
from .trading_submit_params import TradingSubmitParams as TradingSubmitParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["OrderBook"]


class OrderBook(BaseModel):
    asks: Optional[List[List[str]]] = None

    bids: Optional[List[List[str]]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .credit import Credit as Credit
from .balance import Balance as Balance
from .portfolio import Portfolio as Portfolio
from .open_position import OpenPosition as OpenPosition



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["Instrument"]


class Instrument(BaseModel):
    base_asset: Optional[str] = FieldInfo(alias="baseAsset", default=None)

    quote_asset: Optional[str] = FieldInfo(alias="quoteAsset", default=None)

    symbol: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .credit import (
    CreditResource,
    AsyncCreditResource,
    CreditResourceWithRawResponse,
    AsyncCreditResourceWithRawResponse,
    CreditResourceWithStreamingResponse,
    AsyncCreditResourceWithStreamingResponse,
)
from .balance import (
    BalanceResource,
    AsyncBalanceResource,
    BalanceResourceWithRawResponse,
    AsyncBalanceResourceWithRawResponse,
    BalanceResourceWithStreamingResponse,
    AsyncBalanceResourceWithStreamingResponse,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .open_position import (
    OpenPositionResource,
    AsyncOpenPositionResource,
    OpenPositionResourceWithRawResponse,
    AsyncOpenPositionResourceWithRawResponse,
    OpenPositionResourceWithStreamingResponse,
    AsyncOpenPositionResourceWithStreamingResponse,
)
from ..._base_client import make_request_options
from ...types.portfolio.portfolio import Portfolio

__all__ = ["PortfolioResource", "AsyncPortfolioResource"]


class PortfolioResource(SyncAPIResource):
    @cached_property
    def balance(self) -> BalanceResource:
        return BalanceResource(self._client)

    @cached_property
    def open_position(self) -> OpenPositionResource:
        return OpenPositionResource(self._client)

    @cached_property
    def credit(self) -> CreditResource:
        return CreditResource(self._client)

    @cached_property
    def with_raw_response(self) -> PortfolioResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return PortfolioResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PortfolioResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return PortfolioResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Portfolio:
        """Get portfolio data"""
        return self._get(
            "/portfolio",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Portfolio,
        )

    def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Portfolio:
        """Get portfolio data"""
        return self._get(
            "/portfolio",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Portfolio,
        )


class AsyncPortfolioResource(AsyncAPIResource):
    @cached_property
    def balance(self) -> AsyncBalanceResource:
        return AsyncBalanceResource(self._client)

    @cached_property
    def open_position(self) -> AsyncOpenPositionResource:
        return AsyncOpenPositionResource(self._client)

    @cached_property
    def credit(self) -> AsyncCreditResource:
        return AsyncCreditResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPortfolioResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPortfolioResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPortfolioResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return AsyncPortfolioResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Portfolio:
        """Get portfolio data"""
        return await self._get(
            "/portfolio",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Portfolio,
        )

    async def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Portfolio:
        """Get portfolio data"""
        return await self._get(
            "/portfolio",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Portfolio,
        )


class PortfolioResourceWithRawResponse:
    def __init__(self, portfolio: PortfolioResource) -> None:
        self._portfolio = portfolio

        self.retrieve = to_raw_response_wrapper(
            portfolio.retrieve,
        )
        self.get = to_raw_response_wrapper(
            portfolio.get,
        )

    @cached_property
    def balance(self) -> BalanceResourceWithRawResponse:
        return BalanceResourceWithRawResponse(self._portfolio.balance)

    @cached_property
    def open_position(self) -> OpenPositionResourceWithRawResponse:
        return OpenPositionResourceWithRawResponse(self._portfolio.open_position)

    @cached_property
    def credit(self) -> CreditResourceWithRawResponse:
        return CreditResourceWithRawResponse(self._portfolio.credit)


class AsyncPortfolioResourceWithRawResponse:
    def __init__(self, portfolio: AsyncPortfolioResource) -> None:
        self._portfolio = portfolio

        self.retrieve = async_to_raw_response_wrapper(
            portfolio.retrieve,
        )
        self.get = async_to_raw_response_wrapper(
            portfolio.get,
        )

    @cached_property
    def balance(self) -> AsyncBalanceResourceWithRawResponse:
        return AsyncBalanceResourceWithRawResponse(self._portfolio.balance)

    @cached_property
    def open_position(self) -> AsyncOpenPositionResourceWithRawResponse:
        return AsyncOpenPositionResourceWithRawResponse(self._portfolio.open_position)

    @cached_property
    def credit(self) -> AsyncCreditResourceWithRawResponse:
        return AsyncCreditResourceWithRawResponse(self._portfolio.credit)


class PortfolioResourceWithStreamingResponse:
    def __init__(self, portfolio: PortfolioResource) -> None:
        self._portfolio = portfolio

        self.retrieve = to_streamed_response_wrapper(
            portfolio.retrieve,
        )
        self.get = to_streamed_response_wrapper(
            portfolio.get,
        )

    @cached_property
    def balance(self) -> BalanceResourceWithStreamingResponse:
        return BalanceResourceWithStreamingResponse(self._portfolio.balance)

    @cached_property
    def open_position(self) -> OpenPositionResourceWithStreamingResponse:
        return OpenPositionResourceWithStreamingResponse(self._portfolio.open_position)

    @cached_property
    def credit(self) -> CreditResourceWithStreamingResponse:
        return CreditResourceWithStreamingResponse(self._portfolio.credit)


class AsyncPortfolioResourceWithStreamingResponse:
    def __init__(self, portfolio: AsyncPortfolioResource) -> None:
        self._portfolio = portfolio

        self.retrieve = async_to_streamed_response_wrapper(
            portfolio.retrieve,
        )
        self.get = async_to_streamed_response_wrapper(
            portfolio.get,
        )

    @cached_property
    def balance(self) -> AsyncBalanceResourceWithStreamingResponse:
        return AsyncBalanceResourceWithStreamingResponse(self._portfolio.balance)

    @cached_property
    def open_position(self) -> AsyncOpenPositionResourceWithStreamingResponse:
        return AsyncOpenPositionResourceWithStreamingResponse(self._portfolio.open_position)

    @cached_property
    def credit(self) -> AsyncCreditResourceWithStreamingResponse:
        return AsyncCreditResourceWithStreamingResponse(self._portfolio.credit)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .order import Order

__all__ = ["TradingListResponse"]

TradingListResponse: TypeAlias = List[Order]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .kline import (
    KlineResource,
    AsyncKlineResource,
    KlineResourceWithRawResponse,
    AsyncKlineResourceWithRawResponse,
    KlineResourceWithStreamingResponse,
    AsyncKlineResourceWithStreamingResponse,
)
from .market import (
    MarketResource,
    AsyncMarketResource,
    MarketResourceWithRawResponse,
    AsyncMarketResourceWithRawResponse,
    MarketResourceWithStreamingResponse,
    AsyncMarketResourceWithStreamingResponse,
)
from .ticker import (
    TickerResource,
    AsyncTickerResource,
    TickerResourceWithRawResponse,
    AsyncTickerResourceWithRawResponse,
    TickerResourceWithStreamingResponse,
    AsyncTickerResourceWithStreamingResponse,
)
from .instrument import (
    InstrumentResource,
    AsyncInstrumentResource,
    InstrumentResourceWithRawResponse,
    AsyncInstrumentResourceWithRawResponse,
    InstrumentResourceWithStreamingResponse,
    AsyncInstrumentResourceWithStreamingResponse,
)
from .order_book import (
    OrderBookResource,
    AsyncOrderBookResource,
    OrderBookResourceWithRawResponse,
    AsyncOrderBookResourceWithRawResponse,
    OrderBookResourceWithStreamingResponse,
    AsyncOrderBookResourceWithStreamingResponse,
)

__all__ = [
    "InstrumentResource",
    "AsyncInstrumentResource",
    "InstrumentResourceWithRawResponse",
    "AsyncInstrumentResourceWithRawResponse",
    "InstrumentResourceWithStreamingResponse",
    "AsyncInstrumentResourceWithStreamingResponse",
    "OrderBookResource",
    "AsyncOrderBookResource",
    "OrderBookResourceWithRawResponse",
    "AsyncOrderBookResourceWithRawResponse",
    "OrderBookResourceWithStreamingResponse",
    "AsyncOrderBookResourceWithStreamingResponse",
    "TickerResource",
    "AsyncTickerResource",
    "TickerResourceWithRawResponse",
    "AsyncTickerResourceWithRawResponse",
    "TickerResourceWithStreamingResponse",
    "AsyncTickerResourceWithStreamingResponse",
    "KlineResource",
    "AsyncKlineResource",
    "KlineResourceWithRawResponse",
    "AsyncKlineResourceWithRawResponse",
    "KlineResourceWithStreamingResponse",
    "AsyncKlineResourceWithStreamingResponse",
    "MarketResource",
    "AsyncMarketResource",
    "MarketResourceWithRawResponse",
    "AsyncMarketResourceWithRawResponse",
    "MarketResourceWithStreamingResponse",
    "AsyncMarketResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import trading_submit_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..types.order import Order
from .._base_client import make_request_options
from ..types.trading_list_response import TradingListResponse

__all__ = ["TradingResource", "AsyncTradingResource"]


class TradingResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TradingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return TradingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TradingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return TradingResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TradingListResponse:
        """Get historical orders"""
        return self._get(
            "/trading/orders",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TradingListResponse,
        )

    def submit(
        self,
        *,
        order_id: str | NotGiven = NOT_GIVEN,
        price: str | NotGiven = NOT_GIVEN,
        quantity: str | NotGiven = NOT_GIVEN,
        side: Literal["buy", "sell"] | NotGiven = NOT_GIVEN,
        symbol: str | NotGiven = NOT_GIVEN,
        type: Literal["market", "limit"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Order:
        """
        Submit a new order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/trading/order",
            body=maybe_transform(
                {
                    "order_id": order_id,
                    "price": price,
                    "quantity": quantity,
                    "side": side,
                    "symbol": symbol,
                    "type": type,
                },
                trading_submit_params.TradingSubmitParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Order,
        )


class AsyncTradingResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTradingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTradingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTradingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return AsyncTradingResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TradingListResponse:
        """Get historical orders"""
        return await self._get(
            "/trading/orders",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TradingListResponse,
        )

    async def submit(
        self,
        *,
        order_id: str | NotGiven = NOT_GIVEN,
        price: str | NotGiven = NOT_GIVEN,
        quantity: str | NotGiven = NOT_GIVEN,
        side: Literal["buy", "sell"] | NotGiven = NOT_GIVEN,
        symbol: str | NotGiven = NOT_GIVEN,
        type: Literal["market", "limit"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Order:
        """
        Submit a new order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/trading/order",
            body=await async_maybe_transform(
                {
                    "order_id": order_id,
                    "price": price,
                    "quantity": quantity,
                    "side": side,
                    "symbol": symbol,
                    "type": type,
                },
                trading_submit_params.TradingSubmitParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Order,
        )


class TradingResourceWithRawResponse:
    def __init__(self, trading: TradingResource) -> None:
        self._trading = trading

        self.list = to_raw_response_wrapper(
            trading.list,
        )
        self.submit = to_raw_response_wrapper(
            trading.submit,
        )


class AsyncTradingResourceWithRawResponse:
    def __init__(self, trading: AsyncTradingResource) -> None:
        self._trading = trading

        self.list = async_to_raw_response_wrapper(
            trading.list,
        )
        self.submit = async_to_raw_response_wrapper(
            trading.submit,
        )


class TradingResourceWithStreamingResponse:
    def __init__(self, trading: TradingResource) -> None:
        self._trading = trading

        self.list = to_streamed_response_wrapper(
            trading.list,
        )
        self.submit = to_streamed_response_wrapper(
            trading.submit,
        )


class AsyncTradingResourceWithStreamingResponse:
    def __init__(self, trading: AsyncTradingResource) -> None:
        self._trading = trading

        self.list = async_to_streamed_response_wrapper(
            trading.list,
        )
        self.submit = async_to_streamed_response_wrapper(
            trading.submit,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .kline import Kline as Kline
from .ticker import Ticker as Ticker
from .instrument import Instrument as Instrument
from .order_book import OrderBook as OrderBook



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .balance import Balance
from ..._models import BaseModel

__all__ = ["Portfolio"]


class Portfolio(BaseModel):
    assets: Optional[List[Balance]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .market import (
    MarketResource,
    AsyncMarketResource,
    MarketResourceWithRawResponse,
    AsyncMarketResourceWithRawResponse,
    MarketResourceWithStreamingResponse,
    AsyncMarketResourceWithStreamingResponse,
)
from .account import (
    AccountResource,
    AsyncAccountResource,
    AccountResourceWithRawResponse,
    AsyncAccountResourceWithRawResponse,
    AccountResourceWithStreamingResponse,
    AsyncAccountResourceWithStreamingResponse,
)
from .trading import (
    TradingResource,
    AsyncTradingResource,
    TradingResourceWithRawResponse,
    AsyncTradingResourceWithRawResponse,
    TradingResourceWithStreamingResponse,
    AsyncTradingResourceWithStreamingResponse,
)
from .portfolio import (
    PortfolioResource,
    AsyncPortfolioResource,
    PortfolioResourceWithRawResponse,
    AsyncPortfolioResourceWithRawResponse,
    PortfolioResourceWithStreamingResponse,
    AsyncPortfolioResourceWithStreamingResponse,
)

__all__ = [
    "TradingResource",
    "AsyncTradingResource",
    "TradingResourceWithRawResponse",
    "AsyncTradingResourceWithRawResponse",
    "TradingResourceWithStreamingResponse",
    "AsyncTradingResourceWithStreamingResponse",
    "MarketResource",
    "AsyncMarketResource",
    "MarketResourceWithRawResponse",
    "AsyncMarketResourceWithRawResponse",
    "MarketResourceWithStreamingResponse",
    "AsyncMarketResourceWithStreamingResponse",
    "PortfolioResource",
    "AsyncPortfolioResource",
    "PortfolioResourceWithRawResponse",
    "AsyncPortfolioResourceWithRawResponse",
    "PortfolioResourceWithStreamingResponse",
    "AsyncPortfolioResourceWithStreamingResponse",
    "AccountResource",
    "AsyncAccountResource",
    "AccountResourceWithRawResponse",
    "AsyncAccountResourceWithRawResponse",
    "AccountResourceWithStreamingResponse",
    "AsyncAccountResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["OpenPosition"]


class OpenPosition(BaseModel):
    entry_price: Optional[str] = FieldInfo(alias="entryPrice", default=None)

    position_amt: Optional[str] = FieldInfo(alias="positionAmt", default=None)

    symbol: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .account import (
    AccountResource,
    AsyncAccountResource,
    AccountResourceWithRawResponse,
    AsyncAccountResourceWithRawResponse,
    AccountResourceWithStreamingResponse,
    AsyncAccountResourceWithStreamingResponse,
)
from .userdata import (
    UserdataResource,
    AsyncUserdataResource,
    UserdataResourceWithRawResponse,
    AsyncUserdataResourceWithRawResponse,
    UserdataResourceWithStreamingResponse,
    AsyncUserdataResourceWithStreamingResponse,
)

__all__ = [
    "UserdataResource",
    "AsyncUserdataResource",
    "UserdataResourceWithRawResponse",
    "AsyncUserdataResourceWithRawResponse",
    "UserdataResourceWithStreamingResponse",
    "AsyncUserdataResourceWithStreamingResponse",
    "AccountResource",
    "AsyncAccountResource",
    "AccountResourceWithRawResponse",
    "AsyncAccountResourceWithRawResponse",
    "AccountResourceWithStreamingResponse",
    "AsyncAccountResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["UserData"]


class UserData(BaseModel):
    user_id: Optional[str] = FieldInfo(alias="userId", default=None)

    username: Optional[str] = None
